@@ -43,6 +43,7 @@ import org.apache.kyuubi.operation.{ArrayFetchIterator, OperationHandle, Operati
 import org.apache.kyuubi.operation.OperationState.OperationState
 import org.apache.kyuubi.operation.log.OperationLog
 import org.apache.kyuubi.session.Session
+import org.apache.kyuubi.util.TempFileCleanupUtils
 import org.apache.kyuubi.util.reflect.DynFields
 
 class ExecutePython(
@@ -126,7 +127,6 @@ class ExecutePython(
           val ke =
             KyuubiSQLException("Error submitting python in background", rejected)
           setOperationException(ke)
-          shutdownTimeoutMonitor()
           throw ke
       }
     } else {
@@ -399,7 +399,7 @@ object ExecutePython extends Logging {
     val source = getClass.getClassLoader.getResourceAsStream(s"python/$pyfile")
 
     val file = new File(pythonPath.toFile, pyfile)
-    file.deleteOnExit()
+    TempFileCleanupUtils.deleteOnExit(file)
 
     val sink = new FileOutputStream(file)
     val buf = new Array[Byte](1024)
