@@ -19,9 +19,7 @@ package org.apache.kyuubi.engine.spark.operation
 
 import java.lang.{Boolean => JBoolean}
 import java.sql.Statement
-import java.util.{Locale, Set => JSet}
-
-import scala.util.Try
+import java.util.Locale
 
 import org.apache.spark.{KyuubiSparkContextHelper, TaskContext}
 import org.apache.spark.scheduler.{SparkListener, SparkListenerJobStart}
@@ -29,7 +27,7 @@ import org.apache.spark.sql.{QueryTest, Row, SparkSession}
 import org.apache.spark.sql.catalyst.InternalRow
 import org.apache.spark.sql.catalyst.plans.logical.Project
 import org.apache.spark.sql.execution.{CollectLimitExec, LocalTableScanExec, QueryExecution, SparkPlan}
-import org.apache.spark.sql.execution.adaptive.{AdaptiveSparkPlanExec, QueryStageExec}
+import org.apache.spark.sql.execution.adaptive.AdaptiveSparkPlanExec
 import org.apache.spark.sql.execution.exchange.Exchange
 import org.apache.spark.sql.execution.joins.{BroadcastHashJoinExec, SortMergeJoinExec}
 import org.apache.spark.sql.execution.metric.SparkMetricsTestUtils
@@ -45,7 +43,6 @@ import org.apache.kyuubi.engine.spark.{SparkSQLEngine, WithSparkSQLEngine}
 import org.apache.kyuubi.engine.spark.session.SparkSessionImpl
 import org.apache.kyuubi.operation.SparkDataTypeTests
 import org.apache.kyuubi.util.reflect.{DynFields, DynMethods}
-import org.apache.kyuubi.util.reflect.ReflectUtils._
 
 class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTypeTests
   with SparkMetricsTestUtils {
@@ -166,7 +163,6 @@ class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTyp
         sparkPlan.schema,
         "",
         true,
-        true, // spark.sql.execution.arrow.useLargeVarTypes
         KyuubiSparkContextHelper.dummyTaskContext())
       assert(rows.size == expectSize)
     }
@@ -191,12 +187,9 @@ class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTyp
       returnSize.foreach { size =>
         val df = spark.sql(s"select * from t_1 limit $size")
         val headPlan = df.queryExecution.executedPlan.collectLeaves().head
-        if (SPARK_ENGINE_RUNTIME_VERSION >= "3.2") {
-          assert(headPlan.isInstanceOf[AdaptiveSparkPlanExec])
-          val finalPhysicalPlan =
-            SparkDatasetHelper.finalPhysicalPlan(headPlan.asInstanceOf[AdaptiveSparkPlanExec])
-          assert(finalPhysicalPlan.isInstanceOf[CollectLimitExec])
-        }
+        assert(headPlan.isInstanceOf[AdaptiveSparkPlanExec])
+        val finalPhysicalPlan = headPlan.asInstanceOf[AdaptiveSparkPlanExec].finalPhysicalPlan
+        assert(finalPhysicalPlan.isInstanceOf[CollectLimitExec])
         if (size > 1000) {
           runAndCheck(df.queryExecution.executedPlan, 1000)
         } else {
@@ -254,11 +247,7 @@ class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTyp
           |) LIMIT 1
           |""".stripMargin)
       val smj = plan.collect { case smj: SortMergeJoinExec => smj }
-      val bhj = (adaptivePlan match {
-        // SPARK-51008 (4.0.0) adds ResultQueryStageExec
-        case queryStage: QueryStageExec => queryStage.plan
-        case plan => plan
-      }).collect { case bhj: BroadcastHashJoinExec => bhj }
+      val bhj = adaptivePlan.collect { case bhj: BroadcastHashJoinExec => bhj }
       assert(smj.size == 1)
       assert(bhj.size == 1)
     }
@@ -305,11 +294,7 @@ class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTyp
     val listener = new JobCountListener
     val l2 = new SQLMetricsListener
     val nodeName = spark.sql("SHOW TABLES").queryExecution.executedPlan.getClass.getName
-    if (SPARK_ENGINE_RUNTIME_VERSION < "3.2") {
-      assert(nodeName == "org.apache.spark.sql.execution.command.ExecutedCommandExec")
-    } else {
-      assert(nodeName == "org.apache.spark.sql.execution.CommandResultExec")
-    }
+    assert(nodeName == "org.apache.spark.sql.execution.CommandResultExec")
     withJdbcStatement("table_1") { statement =>
       statement.executeQuery("CREATE TABLE table_1 (id bigint) USING parquet")
       withSparkListener(listener) {
@@ -321,15 +306,8 @@ class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTyp
       }
     }
 
-    if (SPARK_ENGINE_RUNTIME_VERSION < "3.2") {
-      // Note that before Spark 3.2, a LocalTableScan SparkPlan will be submitted, and the issue of
-      // preventing LocalTableScan from triggering a job submission was addressed in [KYUUBI #4710].
-      assert(l2.queryExecution.executedPlan.getClass.getName ==
-        "org.apache.spark.sql.execution.LocalTableScanExec")
-    } else {
-      assert(l2.queryExecution.executedPlan.getClass.getName ==
-        "org.apache.spark.sql.execution.CommandResultExec")
-    }
+    assert(l2.queryExecution.executedPlan.getClass.getName ==
+      "org.apache.spark.sql.execution.CommandResultExec")
     assert(listener.numJobs == 0)
   }
 
@@ -385,7 +363,6 @@ class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTyp
 
   test("post CommandResultExec driver-side metrics") {
     spark.sql("show tables").show(truncate = false)
-    assume(SPARK_ENGINE_RUNTIME_VERSION >= "3.2")
     val expectedMetrics = Map(
       0L -> (("CommandResult", Map("number of output rows" -> "2"))))
     withTables("table_1", "table_2") {
@@ -500,7 +477,7 @@ class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTyp
       }
     }
     (keys, values).zipped.foreach { (k, v) =>
-      if (isStaticConfigKey(k)) {
+      if (SQLConf.isStaticConfigKey(k)) {
         throw new KyuubiException(s"Cannot modify the value of a static config: $k")
       }
       conf.setConfString(k, v)
@@ -528,77 +505,49 @@ class SparkArrowbasedOperationSuite extends WithSparkSQLEngine with SparkDataTyp
     }
   }
 
-  /**
-   * This method provides a reflection-based implementation of [[SQLConf.isStaticConfigKey]] to
-   * adapt Spark 3.1
-   *
-   * TODO: Once we drop support for Spark 3.1, we can directly call
-   * [[SQLConf.isStaticConfigKey()]].
-   */
-  private def isStaticConfigKey(key: String): Boolean =
-    getField[JSet[String]]((SQLConf.getClass, SQLConf), "staticConfKeys").contains(key)
-
+  // the signature of function [[ArrowConverters.fromBatchIterator]] is changed in SPARK-43528
+  // (since Spark 3.5)
   private lazy val fromBatchIteratorMethod = DynMethods.builder("fromBatchIterator")
-    .hiddenImpl( // SPARK-51079: Spark 4.0 or later
-      "org.apache.spark.sql.execution.arrow.ArrowConverters$",
-      classOf[Iterator[Array[Byte]]],
-      classOf[StructType],
-      classOf[String],
-      classOf[Boolean],
-      classOf[Boolean],
-      classOf[TaskContext])
-    .hiddenImpl( // SPARK-43528: Spark 3.5
-      "org.apache.spark.sql.execution.arrow.ArrowConverters$",
-      classOf[Iterator[Array[Byte]]],
-      classOf[StructType],
-      classOf[String],
-      classOf[Boolean],
-      classOf[TaskContext])
     .hiddenImpl( // for Spark 3.4 or previous
       "org.apache.spark.sql.execution.arrow.ArrowConverters$",
       classOf[Iterator[Array[Byte]]],
       classOf[StructType],
       classOf[String],
       classOf[TaskContext])
-    .buildChecked()
-
-  private lazy val arrowConvertersObject = DynFields.builder()
-    .impl("org.apache.spark.sql.execution.arrow.ArrowConverters$", "MODULE$")
-    .buildStaticChecked[Any]()
-    .get()
+    .hiddenImpl( // for Spark 3.5 or later
+      "org.apache.spark.sql.execution.arrow.ArrowConverters$",
+      classOf[Iterator[Array[Byte]]],
+      classOf[StructType],
+      classOf[String],
+      classOf[Boolean],
+      classOf[TaskContext])
+    .build()
 
   def fromBatchIterator(
       arrowBatchIter: Iterator[Array[Byte]],
       schema: StructType,
       timeZoneId: String,
       errorOnDuplicatedFieldNames: JBoolean,
-      largeVarTypes: JBoolean,
-      context: TaskContext): Iterator[InternalRow] =
-    Try { // SPARK-51079: Spark 4.0 or later
-      fromBatchIteratorMethod.invokeChecked[Iterator[InternalRow]](
-        arrowConvertersObject,
-        arrowBatchIter,
-        schema,
-        timeZoneId,
-        errorOnDuplicatedFieldNames,
-        largeVarTypes,
-        context)
-    }.recover { case _: Exception => // SPARK-43528: Spark 3.5
-      fromBatchIteratorMethod.invokeChecked[Iterator[InternalRow]](
-        arrowConvertersObject,
+      context: TaskContext): Iterator[InternalRow] = {
+    val className = "org.apache.spark.sql.execution.arrow.ArrowConverters$"
+    val instance = DynFields.builder().impl(className, "MODULE$").build[Object]().get(null)
+    if (SPARK_ENGINE_RUNTIME_VERSION >= "3.5") {
+      fromBatchIteratorMethod.invoke[Iterator[InternalRow]](
+        instance,
         arrowBatchIter,
         schema,
         timeZoneId,
         errorOnDuplicatedFieldNames,
         context)
-    }.recover { case _: Exception => // for Spark 3.4 or previous
-      fromBatchIteratorMethod.invokeChecked[Iterator[InternalRow]](
-        arrowConvertersObject,
+    } else {
+      fromBatchIteratorMethod.invoke[Iterator[InternalRow]](
+        instance,
         arrowBatchIter,
         schema,
         timeZoneId,
         context)
-    }.get
+    }
+  }
 
   class JobCountListener extends SparkListener {
     var numJobs = 0
