@@ -21,6 +21,7 @@ import static org.apache.kyuubi.jdbc.hive.JdbcConnectionParams.*;
 import static org.apache.kyuubi.jdbc.hive.Utils.HIVE_SERVER2_RETRY_KEY;
 import static org.apache.kyuubi.jdbc.hive.Utils.HIVE_SERVER2_RETRY_TRUE;
 
+import com.google.common.base.Preconditions;
 import java.io.*;
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.InvocationTargetException;
@@ -453,19 +454,33 @@ public class KyuubiConnection implements SQLConnection, KyuubiLoggable {
     if (!isSaslAuthMode()) {
       requestInterceptor = null;
     } else if (isPlainSaslAuthMode()) {
-      /*
-       * Add an interceptor to pass username/password in the header. In https mode, the entire
-       * information is encrypted
-       */
-      requestInterceptor =
-          new HttpBasicAuthInterceptor(
-              getUserName(),
-              getPassword(),
-              cookieStore,
-              cookieName,
-              useSsl,
-              additionalHttpHeaders,
-              customCookies);
+      if (isJwtAuthMode()) {
+        final String signedJwt = getJWT();
+        Preconditions.checkArgument(
+            signedJwt != null && !signedJwt.isEmpty(),
+            "For jwt auth mode," + " a signed jwt must be provided");
+        /*
+         * Add an interceptor to pass jwt token in the header. In https mode, the entire
+         * information is encrypted
+         */
+        requestInterceptor =
+            new HttpJwtAuthRequestInterceptor(
+                signedJwt, cookieStore, cookieName, useSsl, additionalHttpHeaders, customCookies);
+      } else {
+        /*
+         * Add an interceptor to pass username/password in the header. In https mode, the entire
+         * information is encrypted
+         */
+        requestInterceptor =
+            new HttpBasicAuthInterceptor(
+                getUserName(),
+                getPassword(),
+                cookieStore,
+                cookieName,
+                useSsl,
+                additionalHttpHeaders,
+                customCookies);
+      }
     } else {
       // Configure http client for kerberos-based authentication
       Subject subject = createSubject();
@@ -588,6 +603,38 @@ public class KyuubiConnection implements SQLConnection, KyuubiLoggable {
     return httpClientBuilder.build();
   }
 
+  private String getJWT() {
+    String jwtCredential = getJWTStringFromSession();
+    if (jwtCredential == null || jwtCredential.isEmpty()) {
+      jwtCredential = getJWTStringFromEnv();
+    }
+    return jwtCredential;
+  }
+
+  private String getJWTStringFromEnv() {
+    String jwtCredential = System.getenv(JdbcConnectionParams.AUTH_JWT_ENV);
+    if (jwtCredential == null || jwtCredential.isEmpty()) {
+      LOG.debug("No JWT is specified in env variable {}", JdbcConnectionParams.AUTH_JWT_ENV);
+    } else {
+      int startIndex = Math.max(0, jwtCredential.length() - 7);
+      String lastSevenChars = jwtCredential.substring(startIndex);
+      LOG.debug("Fetched JWT (ends with {}) from the env.", lastSevenChars);
+    }
+    return jwtCredential;
+  }
+
+  private String getJWTStringFromSession() {
+    String jwtCredential = sessConfMap.get(JdbcConnectionParams.AUTH_TYPE_JWT_KEY);
+    if (jwtCredential == null || jwtCredential.isEmpty()) {
+      LOG.debug("No JWT is specified in connection string.");
+    } else {
+      int startIndex = Math.max(0, jwtCredential.length() - 7);
+      String lastSevenChars = jwtCredential.substring(startIndex);
+      LOG.debug("Fetched JWT (ends with {}) from the session.", lastSevenChars);
+    }
+    return jwtCredential;
+  }
+
   /** Create underlying SSL or non-SSL transport */
   private TTransport createUnderlyingTransport() throws TTransportException, SQLException {
     int maxMessageSize = getMaxMessageSize();
@@ -832,8 +879,8 @@ public class KyuubiConnection implements SQLConnection, KyuubiLoggable {
 
       if (launchEngineOpHandleGuid != null && launchEngineOpHandleSecret != null) {
         try {
-          byte[] guidBytes = Base64.getMimeDecoder().decode(launchEngineOpHandleGuid);
-          byte[] secretBytes = Base64.getMimeDecoder().decode(launchEngineOpHandleSecret);
+          byte[] guidBytes = Base64.getDecoder().decode(launchEngineOpHandleGuid);
+          byte[] secretBytes = Base64.getDecoder().decode(launchEngineOpHandleSecret);
           THandleIdentifier handleIdentifier =
               new THandleIdentifier(ByteBuffer.wrap(guidBytes), ByteBuffer.wrap(secretBytes));
           launchEngineOpHandle =
@@ -952,6 +999,12 @@ public class KyuubiConnection implements SQLConnection, KyuubiLoggable {
     return isSaslAuthMode() && !hasSessionValue(AUTH_PRINCIPAL);
   }
 
+  private boolean isJwtAuthMode() {
+    return JdbcConnectionParams.AUTH_TYPE_JWT.equalsIgnoreCase(
+            sessConfMap.get(JdbcConnectionParams.AUTH_TYPE))
+        || sessConfMap.containsKey(JdbcConnectionParams.AUTH_TYPE_JWT_KEY);
+  }
+
   private boolean isKerberosAuthMode() {
     return isSaslAuthMode() && hasSessionValue(AUTH_PRINCIPAL);
   }
