@@ -24,17 +24,17 @@ import java.util.Locale
 
 import scala.util.control.NonFatal
 
+import org.apache.commons.lang3.StringUtils
+
 import org.apache.kyuubi.{KyuubiException, Utils}
 import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.engine.KubernetesApplicationOperation.LABEL_KYUUBI_UNIQUE_KEY
 import org.apache.kyuubi.engine.flink.FlinkProcessBuilder
 import org.apache.kyuubi.engine.spark.SparkProcessBuilder
-import org.apache.kyuubi.server.metadata.MetadataManager
 import org.apache.kyuubi.service.AbstractService
 import org.apache.kyuubi.util.reflect.ReflectUtils._
 
-class KyuubiApplicationManager(metadataManager: Option[MetadataManager])
-  extends AbstractService("KyuubiApplicationManager") {
+class KyuubiApplicationManager extends AbstractService("KyuubiApplicationManager") {
 
   // TODO: maybe add a configuration is better
   private val operations =
@@ -43,7 +43,7 @@ class KyuubiApplicationManager(metadataManager: Option[MetadataManager])
   override def initialize(conf: KyuubiConf): Unit = {
     operations.foreach { op =>
       try {
-        op.initialize(conf, metadataManager)
+        op.initialize(conf)
       } catch {
         case NonFatal(e) => warn(s"Error starting ${op.getClass.getSimpleName}: ${e.getMessage}")
       }
@@ -194,9 +194,11 @@ object KyuubiApplicationManager {
       case ("FLINK", Some("YARN")) =>
         // running flink on other platforms is not yet supported
         setupFlinkYarnTag(applicationTag, conf)
-      // other engine types are running locally yet
       case ("HIVE", Some("YARN")) =>
         setupEngineYarnModeTag(applicationTag, conf)
+      case ("JDBC", Some("YARN")) =>
+        setupEngineYarnModeTag(applicationTag, conf)
+      // other engine types are running locally yet
       case _ =>
     }
   }
@@ -211,4 +213,9 @@ object KyuubiApplicationManager {
       case _ =>
     }
   }
+
+  def sessionUploadFolderPath(sessionId: String): Path = {
+    require(StringUtils.isNotBlank(sessionId))
+    uploadWorkDir.resolve(sessionId)
+  }
 }
