@@ -23,6 +23,8 @@ import java.util.concurrent.{SynchronousQueue, ThreadPoolExecutor, TimeUnit}
 import javax.security.sasl.AuthenticationException
 import javax.servlet.{ServletContextEvent, ServletContextListener}
 
+import scala.collection.JavaConverters._
+
 import org.apache.commons.lang3.SystemUtils
 import org.apache.hadoop.conf.Configuration
 import org.eclipse.jetty.http.HttpMethod
@@ -42,7 +44,7 @@ import org.apache.kyuubi.config.KyuubiReservedKeys.{KYUUBI_SESSION_ENGINE_LAUNCH
 import org.apache.kyuubi.metrics.MetricsConstants.{THRIFT_HTTP_CONN_FAIL, THRIFT_HTTP_CONN_OPEN, THRIFT_HTTP_CONN_TOTAL}
 import org.apache.kyuubi.metrics.MetricsSystem
 import org.apache.kyuubi.server.http.ThriftHttpServlet
-import org.apache.kyuubi.server.http.util.SessionManager
+import org.apache.kyuubi.server.http.authentication.AuthenticationFilter
 import org.apache.kyuubi.service.{Serverable, Service, ServiceUtils, TFrontendService}
 import org.apache.kyuubi.service.TFrontendService.{CURRENT_SERVER_CONTEXT, OK_STATUS}
 import org.apache.kyuubi.session.KyuubiSessionImpl
@@ -314,13 +316,30 @@ final class KyuubiTHttpFrontendService(
   }
 
   override protected def getIpAddress: String = {
-    Option(SessionManager.getProxyHttpHeaderIpAddress).getOrElse(SessionManager.getIpAddress)
+    Option(AuthenticationFilter.getUserProxyHeaderIpAddress).getOrElse(
+      AuthenticationFilter.getUserIpAddress)
+  }
+
+  override protected def getProxyUser(
+      sessionConf: java.util.Map[String, String],
+      ipAddress: String,
+      realUser: String): String = {
+    Option(AuthenticationFilter.getProxyUserName) match {
+      case Some(proxyUser) =>
+        val proxyUserConf = Map(PROXY_USER.key -> proxyUser)
+        super.getProxyUser(
+          (sessionConf.asScala ++ proxyUserConf).asJava,
+          ipAddress,
+          realUser)
+      case None => super.getProxyUser(sessionConf, ipAddress, realUser)
+    }
   }
 
   override protected def getRealUserAndSessionUser(req: TOpenSessionReq): (String, String) = {
-    val realUser = getShortName(Option(SessionManager.getUserName).getOrElse(req.getUsername))
+    val realUser = getShortName(Option(AuthenticationFilter.getUserName)
+      .getOrElse(req.getUsername))
     // using the remote ip address instead of that in proxy http header for authentication
-    val ipAddress: String = SessionManager.getIpAddress
+    val ipAddress: String = AuthenticationFilter.getUserIpAddress
     val sessionUser: String = if (req.getConfiguration == null) {
       realUser
     } else {
