@@ -120,8 +120,8 @@ object KubernetesUtils extends Logging {
     opt2.foreach { _ => require(opt1.isEmpty, errMessage) }
   }
 
-  private def getResourceNamePrefix(appName: String, engineRefId: String): String = {
-    s"$appName-$engineRefId"
+  private def getResourceNamePrefix(appName: String, engineRefId: Option[String]): String = {
+    engineRefId.map(refId => s"$appName-$refId").getOrElse(appName)
       .trim
       .toLowerCase(Locale.ROOT)
       .replaceAll("[^a-z0-9\\-]", "-")
@@ -130,21 +130,45 @@ object KubernetesUtils extends Logging {
       .replaceAll("^[0-9]", "x")
   }
 
-  def generateDriverPodName(appName: String, engineRefId: String): String = {
-    val resolvedResourceName = s"kyuubi-${getResourceNamePrefix(appName, engineRefId)}-driver"
-    if (resolvedResourceName.length <= DRIVER_POD_NAME_MAX_LENGTH) {
-      resolvedResourceName
+  def generateDriverPodName(
+      appName: String,
+      engineRefId: String,
+      forciblyRewrite: Boolean): String = {
+    val resourceNamePrefix = if (appName.contains(engineRefId)) {
+      getResourceNamePrefix(appName, None)
     } else {
+      getResourceNamePrefix(appName, Some(engineRefId))
+    }
+    val resolvedResourceName = if (resourceNamePrefix.startsWith("kyuubi-")) {
+      s"$resourceNamePrefix-driver"
+    } else {
+      s"kyuubi-$resourceNamePrefix-driver"
+    }
+    if (forciblyRewrite || resolvedResourceName.length > DRIVER_POD_NAME_MAX_LENGTH) {
       s"kyuubi-$engineRefId-driver"
+    } else {
+      resolvedResourceName
     }
   }
 
-  def generateExecutorPodNamePrefix(appName: String, engineRefId: String): String = {
-    val resolvedResourceName = s"kyuubi-${getResourceNamePrefix(appName, engineRefId)}"
-    if (resolvedResourceName.length <= EXECUTOR_POD_NAME_PREFIX_MAX_LENGTH) {
-      resolvedResourceName
+  def generateExecutorPodNamePrefix(
+      appName: String,
+      engineRefId: String,
+      forciblyRewrite: Boolean): String = {
+    val resourceNamePrefix = if (appName.contains(engineRefId)) {
+      getResourceNamePrefix(appName, None)
     } else {
+      getResourceNamePrefix(appName, Some(engineRefId))
+    }
+    val resolvedResourceName = if (resourceNamePrefix.startsWith("kyuubi-")) {
+      s"$resourceNamePrefix"
+    } else {
+      s"kyuubi-$resourceNamePrefix"
+    }
+    if (forciblyRewrite || resolvedResourceName.length > EXECUTOR_POD_NAME_PREFIX_MAX_LENGTH) {
       s"kyuubi-$engineRefId"
+    } else {
+      resolvedResourceName
     }
   }
 }
