@@ -20,6 +20,7 @@ import overviewRoutes from './overview'
 import managementRoutes from './management'
 import detailRoutes from './detail'
 import swaggerRoutes from './swagger'
+import editorRoutes from './editor'
 
 const routes = [
   {
@@ -38,7 +39,8 @@ const routes = [
       ...overviewRoutes,
       ...managementRoutes,
       ...detailRoutes,
-      ...swaggerRoutes
+      ...swaggerRoutes,
+      ...editorRoutes
     ]
   }
 ]
